The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Type: Package
Title: Standardized Ranking Performance Index for Model Selection
Version: 0.1.0
Maintainer: Santosha Rathod <santoshagriculture@gmail.com>
Description: Flexible implementation of the Standardized Ranking Performance Index (sRPI) for model selection based on multiple evaluation criteria. The package combines multiple statistical measures into a single index to provide an objective and robust ranking of models across calibration, validation, and combined scenarios. It supports evaluation of statistical, machine learning, and other predictive models using user-defined performance criteria. For more details see Aschonitis et al. (2019) <doi:10.1016/j.envsoft.2019.01.005> and Singh et al. (2023) <doi:10.1016/j.ecoinf.2022.101933>.
License: GPL-3
Encoding: UTF-8
LazyData: true
Imports: ggplot2
Depends: R (≥ 3.5)
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-16 19:55:58 UTC; Admin
Author: RN Singh [aut], Sonam [aut], Sudhir Kumar Mishra [aut], Gaurav Chaturvedi [aut], Anil Kumar [aut], Santosha Rathod [aut, cre]
Repository: CRAN
Date/Publication: 2026-04-21 19:00:07 UTC

Example calibration dataset

Description

Example dataset used for sRPI calculation

Usage

cal_example

Format

A data frame with 12 rows and 5 variables


Combine sRPI

Description

Combine sRPI

Usage

combine_srpi(cal, val)

Arguments

cal

Calibration results

val

Validation results

Value

A data frame containing Model, calibration sRPI, validation sRPI, combined sRPI, and final ranking of models.

Examples

data(cal_example)
data(val_example)
criteria <- c("R2","dindex","MBE","RMSE")
type <- c("max","max","min","min")
cal_res <- srpi(cal_example, criteria, type)
val_res <- srpi(val_example, criteria, type)
combine_srpi(cal_res, val_res)


Plot sRPI

Description

Plot sRPI

Usage

plot_srpi(combined, title = "sRPI Plot")

Arguments

combined

Data frame

title

Plot title

Value

No return value. This function generates a plot.

Examples

data(cal_example)
data(val_example)
criteria <- c("R2","dindex","MBE","RMSE")
type <- c("max","max","min","min")
cal_res <- srpi(cal_example, criteria, type)
val_res <- srpi(val_example, criteria, type)
combined <- combine_srpi(cal_res, val_res)
plot_srpi(combined)


Standardized Ranking Performance Index (sRPI)

Description

Standardized Ranking Performance Index (sRPI)

Usage

srpi(data, criteria, type)

Arguments

data

Data frame

criteria

Character vector

type

Character vector

Value

A data frame

Examples

data(cal_example)
criteria <- c("R2","dindex","MBE","RMSE")
type <- c("max","max","min","min")
srpi(cal_example, criteria, type)


Example validation dataset

Description

Example dataset used for sRPI calculation

Usage

val_example

Format

A data frame with 12 rows and 5 variables

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.