| Title: | Standardized Ranking Performance Index for Model Selection |
|---|---|
| Description: | Flexible implementation of the Standardized Ranking Performance Index (sRPI) for model selection based on multiple evaluation criteria. The package combines multiple statistical measures into a single index to provide an objective and robust ranking of models across calibration, validation, and combined scenarios. It supports evaluation of statistical, machine learning, and other predictive models using user-defined performance criteria. For more details see Aschonitis et al. (2019) <doi:10.1016/j.envsoft.2019.01.005> and Singh et al. (2023) <doi:10.1016/j.ecoinf.2022.101933>. |
| Authors: | RN Singh [aut], Sonam [aut], Sudhir Kumar Mishra [aut], Gaurav Chaturvedi [aut], Anil Kumar [aut], Santosha Rathod [aut, cre] |
| Maintainer: | Santosha Rathod <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-22 07:47:46 UTC |
| Source: | https://github.com/cran/srpi |
Example dataset used for sRPI calculation
cal_examplecal_example
A data frame with 12 rows and 5 variables
Combine sRPI
combine_srpi(cal, val)combine_srpi(cal, val)
cal |
Calibration results |
val |
Validation results |
A data frame containing Model, calibration sRPI, validation sRPI, combined sRPI, and final ranking of models.
data(cal_example) data(val_example) criteria <- c("R2","dindex","MBE","RMSE") type <- c("max","max","min","min") cal_res <- srpi(cal_example, criteria, type) val_res <- srpi(val_example, criteria, type) combine_srpi(cal_res, val_res)data(cal_example) data(val_example) criteria <- c("R2","dindex","MBE","RMSE") type <- c("max","max","min","min") cal_res <- srpi(cal_example, criteria, type) val_res <- srpi(val_example, criteria, type) combine_srpi(cal_res, val_res)
Plot sRPI
plot_srpi(combined, title = "sRPI Plot")plot_srpi(combined, title = "sRPI Plot")
combined |
Data frame |
title |
Plot title |
No return value. This function generates a plot.
data(cal_example) data(val_example) criteria <- c("R2","dindex","MBE","RMSE") type <- c("max","max","min","min") cal_res <- srpi(cal_example, criteria, type) val_res <- srpi(val_example, criteria, type) combined <- combine_srpi(cal_res, val_res) plot_srpi(combined)data(cal_example) data(val_example) criteria <- c("R2","dindex","MBE","RMSE") type <- c("max","max","min","min") cal_res <- srpi(cal_example, criteria, type) val_res <- srpi(val_example, criteria, type) combined <- combine_srpi(cal_res, val_res) plot_srpi(combined)
Standardized Ranking Performance Index (sRPI)
srpi(data, criteria, type)srpi(data, criteria, type)
data |
Data frame |
criteria |
Character vector |
type |
Character vector |
A data frame
data(cal_example) criteria <- c("R2","dindex","MBE","RMSE") type <- c("max","max","min","min") srpi(cal_example, criteria, type)data(cal_example) criteria <- c("R2","dindex","MBE","RMSE") type <- c("max","max","min","min") srpi(cal_example, criteria, type)
Example dataset used for sRPI calculation
val_exampleval_example
A data frame with 12 rows and 5 variables